Documentation
¶
Overview ¶
Package models contains auto generated structures used in the open API client for Pixeldrain.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateFileListRequest ¶ added in v0.6.0
type CreateFileListRequest struct {
// If true this list will not be linked to your user account.
// Example: true
Anonymous *bool `json:"anonymous,omitempty"`
// Ordered array of files to add to the list
// Example: [{"description":"First photo of the week, such a beautiful valley","id":"abc123"},{"description":"The week went by so quickly, here's a photo from the plane back","id":"123abc"}]
// Required: true
Files []*ListItem `json:"files"`
// Title of the list.
// Example: My beautiful photos
Title *string `json:"title,omitempty"`
}
CreateFileListRequest create file list request
swagger:model CreateFileListRequest
func (*CreateFileListRequest) ContextValidate ¶ added in v0.6.0
ContextValidate validate this create file list request based on the context it is used
func (*CreateFileListRequest) MarshalBinary ¶ added in v0.6.0
func (m *CreateFileListRequest) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CreateFileListRequest) UnmarshalBinary ¶ added in v0.6.0
func (m *CreateFileListRequest) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type FileInfo ¶ added in v0.6.0
type FileInfo struct {
// How much bandwidth this file used
BandwidthUsed int64 `json:"bandwidth_used,omitempty"`
// Timestamp of last viewed time
// Example: 2019-01-15T17:13:43Z
// Format: date-time
DateLastView strfmt.DateTime `json:"date_last_view,omitempty"`
// Timestamp of uploaded time
// Example: 2019-01-15T17:13:43Z
// Format: date-time
DateUpload strfmt.DateTime `json:"date_upload,omitempty"`
// ID of the newly uploaded file
// Example: abc123
// Required: true
ID *string `json:"id"`
// MIME type of the file
// Example: image/png
MimeType string `json:"mime_type,omitempty"`
// Name of the file
// Example: screenshot.png
Name string `json:"name,omitempty"`
// Size of the file in Bytes
// Example: 5694837
Size int64 `json:"size,omitempty"`
// Link to a thumbnail of this file
// Example: /file/1234abcd/thumbnail
ThumbnailHref string `json:"thumbnail_href,omitempty"`
// Amount of unique file views
// Example: 1234
Views int64 `json:"views,omitempty"`
}
FileInfo file info
swagger:model FileInfo
func (*FileInfo) ContextValidate ¶ added in v0.6.0
ContextValidate validates this file info based on context it is used
func (*FileInfo) MarshalBinary ¶ added in v0.6.0
MarshalBinary interface implementation
func (*FileInfo) UnmarshalBinary ¶ added in v0.6.0
UnmarshalBinary interface implementation
type GetFileListResponse ¶ added in v0.6.0
type GetFileListResponse struct {
// date creqated
// Example: 1513033315
DateCreqated float64 `json:"date_creqated,omitempty"`
// files
Files []*FileInfo `json:"files"`
// id
// Example: L8bhwx
ID string `json:"id,omitempty"`
// success
// Example: true
Success bool `json:"success,omitempty"`
// title
// Example: Rust in Peace
Title string `json:"title,omitempty"`
}
GetFileListResponse get file list response
swagger:model GetFileListResponse
func (*GetFileListResponse) ContextValidate ¶ added in v0.6.0
ContextValidate validate this get file list response based on the context it is used
func (*GetFileListResponse) MarshalBinary ¶ added in v0.6.0
func (m *GetFileListResponse) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetFileListResponse) UnmarshalBinary ¶ added in v0.6.0
func (m *GetFileListResponse) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ListInfo ¶ added in v0.6.0
type ListInfo struct {
// Timestamp of creation time
// Example: 2019-01-15T17:13:43Z
// Format: date-time
DateCreated strfmt.DateTime `json:"date_created,omitempty"`
// The number of files in the list
// Example: 1234
FileCount int64 `json:"file_count,omitempty"`
// ID of the newly uploaded file
// Example: abc123
// Required: true
ID *string `json:"id"`
// Title of the list.
// Example: My beautiful photos
Title *string `json:"title,omitempty"`
}
ListInfo list info
swagger:model ListInfo
func (*ListInfo) ContextValidate ¶ added in v0.6.0
ContextValidate validates this list info based on context it is used
func (*ListInfo) MarshalBinary ¶ added in v0.6.0
MarshalBinary interface implementation
func (*ListInfo) UnmarshalBinary ¶ added in v0.6.0
UnmarshalBinary interface implementation
type ListItem ¶ added in v0.6.0
type ListItem struct {
// Description of the file
// Example: First photo of the week, such a beautiful valley
Description string `json:"description,omitempty"`
// ID of the file
// Example: abc123
// Required: true
ID *string `json:"id"`
}
ListItem list item
swagger:model ListItem
func (*ListItem) ContextValidate ¶ added in v0.6.0
ContextValidate validates this list item based on context it is used
func (*ListItem) MarshalBinary ¶ added in v0.6.0
MarshalBinary interface implementation
func (*ListItem) UnmarshalBinary ¶ added in v0.6.0
UnmarshalBinary interface implementation
type StandardError ¶
type StandardError struct {
// id
// Example: Oh42No
ID string `json:"id,omitempty"`
// message
// Example: Something went wrong while writing the file to disk, the server may be out of storage space.
// Required: true
Message *string `json:"message"`
// success
// Example: false
// Required: true
Success *bool `json:"success"`
// value
// Example: writing
// Required: true
Value *string `json:"value"`
}
StandardError standard error
swagger:model StandardError
func (*StandardError) ContextValidate ¶ added in v0.5.0
ContextValidate validates this standard error based on context it is used
func (*StandardError) MarshalBinary ¶
func (m *StandardError) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*StandardError) UnmarshalBinary ¶
func (m *StandardError) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SuccessResponse ¶ added in v0.6.0
type SuccessResponse struct {
// ID of the created object
// Example: yay137
// Required: true
ID *string `json:"id"`
// success
// Example: true
// Required: true
Success *bool `json:"success"`
}
SuccessResponse success response
swagger:model SuccessResponse
func (*SuccessResponse) ContextValidate ¶ added in v0.6.0
ContextValidate validates this success response based on context it is used
func (*SuccessResponse) MarshalBinary ¶ added in v0.6.0
func (m *SuccessResponse) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SuccessResponse) UnmarshalBinary ¶ added in v0.6.0
func (m *SuccessResponse) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation